@@ -12,7 +12,7 @@ def C_(ctx, s):
     return translated
 
 gettext.bindtextdomain ("caribou",
-                        os.path.join ("/opt/gnome3", "share", "locale"))
+                        os.path.join ("/home/ueno/gnome/install", "share", "locale"))
 
 gettext.textdomain("caribou")
 
